@@ -4,16 +4,13 @@ require 'childprocess/abstract_io'
 require "fcntl"
 
 module ChildProcess
-  autoload :Unix,     'childprocess/unix'
-  autoload :Windows,  'childprocess/windows'
-  autoload :JRuby,    'childprocess/jruby'
 
   @posix_spawn = false
 
   class << self
     def new(*args)
       case os
-      when :macosx, :linux, :solaris, :bsd, :cygwin
+      when :macosx, :linux, :solaris, :bsd, :cygwin, :aix
         if posix_spawn?
           Unix::PosixSpawnProcess.new(args)
         elsif jruby?
@@ -105,6 +102,8 @@ module ChildProcess
           :solaris
         when /bsd/
           :bsd
+        when /aix/
+          :aix
         else
           raise Error, "unknown os: #{host_os.inspect}"
         end
@@ -172,3 +171,7 @@ module ChildProcess
 end # ChildProcess
 
 require 'jruby' if ChildProcess.jruby?
+
+require 'childprocess/unix'    if ChildProcess.unix?
+require 'childprocess/windows' if ChildProcess.windows?
+require 'childprocess/jruby'   if ChildProcess.jruby?
