@@ -1,14 +1,21 @@
 module ChildProcess
-  class Error < StandardError; end
-  class TimeoutError < StandardError; end
-  class SubclassResponsibility < StandardError; end
-  class InvalidEnvironmentVariable < StandardError; end
-  class LaunchError < StandardError; end
+  class Error < StandardError
+  end
 
-  class MissingPlatformError < StandardError
+  class TimeoutError < Error
+  end
+
+  class SubclassResponsibility < Error
+  end
+
+  class InvalidEnvironmentVariable < Error
+  end
+
+  class LaunchError < Error
+  end
+
+  class MissingPlatformError < Error
     def initialize
-      platform = ChildProcess.platform_name
-
       message = "posix_spawn is not yet supported on #{ChildProcess.platform_name} (#{RUBY_PLATFORM}), falling back to default implementation. " +
                 "If you believe this is an error, please file a bug at http://github.com/jarib/childprocess/issues"
 
