@@ -88,10 +88,7 @@ module ChildProcess
         end
 
         if duplex?
-          stdin = @process.getOutputStream.to_io
-          stdin.sync = true
-
-          io._stdin = stdin
+          io._stdin = create_stdin
         else
           @process.getOutputStream.close
         end
@@ -116,6 +113,31 @@ module ChildProcess
         end
       end
 
+      def create_stdin
+        output_stream = @process.getOutputStream
+
+        stdin = output_stream.to_io
+        stdin.sync = true
+        stdin.instance_variable_set(:@childprocess_java_stream, output_stream)
+
+        class << stdin
+          # The stream provided is a BufferedeOutputStream, so we
+          # have to flush it to make the bytes flow to the process
+          def __childprocess_flush__
+            @childprocess_java_stream.flush
+          end
+
+          [:flush, :print, :printf, :putc, :puts, :write, :write_nonblock].each do |m|
+            define_method(m) do |*args|
+              super(*args)
+              self.__childprocess_flush__
+            end
+          end
+        end
+
+        stdin
+      end
+
     end # Process
   end # JRuby
 end # ChildProcess
