@@ -97,20 +97,50 @@ module ChildProcessSpecHelper
   def cat
     if ChildProcess.os == :windows
       ruby(<<-CODE)
-            STDIN.sync  = true
-            STDOUT.sync = true
-
-            puts STDIN.read
+            STDIN.sync = STDOUT.sync = true
+            IO.copy_stream(STDIN, STDOUT)
           CODE
     else
       ChildProcess.build("cat")
     end
   end
 
+  def echo
+    if ChildProcess.os == :windows
+      ruby(<<-CODE)
+            STDIN.sync  = true
+            STDOUT.sync = true
+
+            puts "hello"
+          CODE
+    else
+      ChildProcess.build("echo", "hello")
+    end
+  end
+
   def ruby(code)
     ruby_process(tmp_script(code))
   end
 
+  def with_executable_at(path, &blk)
+    if ChildProcess.os == :windows
+      path << ".cmd"
+      content = "@echo foo"
+    else
+      content = "#!/bin/sh\necho foo"
+    end
+
+    File.open(path, 'w', 0744) { |io| io << content }
+    proc = ChildProcess.build(path)
+
+    begin
+      yield proc
+    ensure
+      proc.stop if proc.alive?
+      File.delete path
+    end
+  end
+
   def exit_timeout
     10
   end
@@ -136,13 +166,22 @@ module ChildProcessSpecHelper
 
   def wait_until(timeout = 10, &blk)
     end_time = Time.now + timeout
+    last_exception = nil
 
     until Time.now >= end_time
-      return if yield
+      begin
+        return if yield
+      rescue RSpec::Expectations::ExpectationNotMetError => ex
+        last_exception = ex
+      end
+
       sleep 0.05
     end
 
-    raise "timed out"
+    msg = "timed out after #{timeout} seconds"
+    msg << ":\n#{last_exception.message}" if last_exception
+
+    raise msg
   end
 
   def can_bind?(host, port)
@@ -152,6 +191,11 @@ module ChildProcessSpecHelper
     false
   end
 
+  def rewind_and_read(io)
+    io.rewind
+    io.read
+  end
+
 end # ChildProcessSpecHelper
 
 Thread.abort_on_exception = true
